@@ -1,4 +1,3 @@
-import warnings
 from math import atan2, degrees
 
 import numpy as np
@@ -37,14 +36,6 @@ class SRTTransform(QtGui.QTransform):
     def getScale(self):
         return self._state['scale']
         
-    def getAngle(self):  
-        warnings.warn(
-            'SRTTransform.getAngle() is deprecated, use SRTTransform.getRotation() instead'
-            'will be removed in 0.13',
-            DeprecationWarning, stacklevel=2
-        )
-        return self.getRotation()
-        
     def getRotation(self):
         return self._state['angle']
         
@@ -179,7 +170,7 @@ if __name__ == '__main__':
 
     from . import widgets
     from .functions import *
-    app = pg.mkQApp()
+    app = pg.mkQApp()  # noqa: qapp stored to avoid gc
     win = QtWidgets.QMainWindow()
     win.show()
     cw = GraphicsView.GraphicsView()
